@@ -1,7 +1,7 @@
 import os
 import pkgutil
 
-from typing import List, Callable, Tuple, Union
+from typing import Callable
 from datetime import datetime
 
 from PySide6.QtCore import QObject, Signal, Slot, QDataStream, QByteArray, Qt
@@ -9,15 +9,16 @@ from PySide6.QtGui import QPixmap, QBrush, QColor, QKeySequence, QShortcut
 from PySide6.QtWidgets import QLabel, QComboBox, QPushButton, QTableWidgetItem
 from PySide6.QtUiTools import QUiLoader
 
-from pupgui2.constants import PROTONDB_COLORS, STEAM_APP_PAGE_URL, AWACY_WEB_URL, PROTONDB_APP_PAGE_URL, LUTRIS_WEB_URL
+from pupgui2.constants import PROTONDB_COLORS, STEAM_APP_PAGE_URL, AWACY_WEB_URL, PROTONDB_APP_PAGE_URL, LUTRIS_WEB_URL, IS_FLATPAK
 from pupgui2.datastructures import AWACYStatus, SteamApp, SteamDeckCompatEnum, LutrisGame, HeroicGame
-from pupgui2.lutrisutil import get_lutris_game_list
+from pupgui2.lutrisutil import get_lutris_game_list, is_lutris_game_using_runner
+from pupgui2.pupgui2shortcutdialog import PupguiShortcutDialog
 from pupgui2.steamutil import steam_update_ctools, get_steam_game_list
 from pupgui2.steamutil import is_steam_running, get_steam_ctool_list
 from pupgui2.steamutil import get_protondb_status
 from pupgui2.heroicutil import get_heroic_game_list, is_heroic_launcher
 from pupgui2.util import list_installed_ctools, sort_compatibility_tool_names, open_webbrowser_thread
-from pupgui2.util import get_install_location_from_directory_name
+from pupgui2.util import get_install_location_from_directory_name, get_random_game_name
 
 
 class PupguiGameListDialog(QObject):
@@ -30,11 +31,11 @@ class PupguiGameListDialog(QObject):
         self.install_dir = install_dir
         self.parent = parent
         self.queued_changes = {}
-        self.games: List[Union[SteamApp, LutrisGame, HeroicGame]] = []
+        self.games: list[SteamApp | LutrisGame | HeroicGame] = []
 
         self.install_loc = get_install_location_from_directory_name(install_dir)
         self.launcher = self.install_loc.get('launcher', '')
-        self.should_show_steam_warning = (is_steam_running() or os.path.exists('/.flatpak-info')) and self.launcher == 'steam'
+        self.should_show_steam_warning = (is_steam_running() or IS_FLATPAK) and self.launcher == 'steam'
 
         self.load_ui()
         self.setup_ui()
@@ -53,6 +54,8 @@ class PupguiGameListDialog(QObject):
         elif is_heroic_launcher(self.launcher):
             self.setup_heroic_list_ui()
 
+        self.ui.btnShortcutEditor.setVisible(self.launcher == 'steam')
+
         self.ui.btnSearch.setVisible(False)
         self.ui.searchBox.setVisible(False)  # Hide searchbox by default
 
@@ -66,6 +69,7 @@ class PupguiGameListDialog(QObject):
         self.ui.btnApply.clicked.connect(self.btn_apply_clicked)
         self.ui.btnSearch.clicked.connect(self.btn_search_clicked)
         self.ui.btnRefreshGames.clicked.connect(self.btn_refresh_games_clicked)
+        self.ui.btnShortcutEditor.clicked.connect(self.btn_shortcut_editor_clicked)
         self.ui.searchBox.textChanged.connect(self.search_gamelist_games)
 
         # Hide Search button and disable shortcut if no games
@@ -74,9 +78,9 @@ class PupguiGameListDialog(QObject):
             QShortcut(QKeySequence.Find, self.ui).activated.connect(self.btn_search_clicked)
 
     def setup_steam_list_ui(self):
-        self.ui.tableGames.setHorizontalHeaderLabels([self.tr('Game'), self.tr('Compatibility Tool'), self.tr('Deck compatibility'), self.tr('Anticheat'), 'ProtonDB'])
+        self.ui.tableGames.setHorizontalHeaderLabels([self.tr('Game'), self.tr('Compatibility Tool'), self.tr('Deck Compatibility'), self.tr('Anticheat'), 'ProtonDB'])
         self.ui.tableGames.horizontalHeaderItem(3).setToolTip('https://areweanticheatyet.com')
-        self.ui.lblSteamRunningWarning.setStyleSheet('QLabel { color: grey; }' if os.path.exists('/.flatpak-info') else self.ui.lblSteamRunningWarning.styleSheet())
+        self.ui.lblSteamRunningWarning.setStyleSheet('QLabel { color: grey; }' if IS_FLATPAK else self.ui.lblSteamRunningWarning.styleSheet())
 
         self.update_game_list_steam()
         self.protondb_status_fetched.connect(self.update_protondb_status)
@@ -107,7 +111,7 @@ class PupguiGameListDialog(QObject):
 
     def update_game_list_steam(self, cached=True):
         """ update the game list for the Steam launcher """
-        self.games = get_steam_game_list(steam_config_folder=self.install_loc.get('vdf_dir'), cached=cached)
+        self.games: list[SteamApp] = get_steam_game_list(steam_config_folder=self.install_loc.get('vdf_dir'), cached=cached)
         ctools = [c if c != 'SteamTinkerLaunch' else 'Proton-stl' for c in sort_compatibility_tool_names(list_installed_ctools(self.install_dir, without_version=True), reverse=True)]
         ctools.extend(t.ctool_name for t in get_steam_ctool_list(steam_config_folder=self.install_loc.get('vdf_dir'), cached=True))
 
@@ -143,8 +147,13 @@ class PupguiGameListDialog(QObject):
             self.ui.tableGames.setItem(i, 4, QTableWidgetItem())
             self.ui.tableGames.setCellWidget(i, 4, btn_fetch_protondb)
 
+            # Steam Deck compatibility 
             lbltxt = self.get_steamdeck_compatibility(game)
-            self.ui.tableGames.setItem(i, 2, QTableWidgetItem(lbltxt))
+
+            lbltxt_item = QTableWidgetItem(lbltxt)
+            lbltxt_item.setToolTip(lbltxt_item.text())
+
+            self.ui.tableGames.setItem(i, 2, lbltxt_item)
 
             # AWACY status
             lblicon = QLabel()
@@ -158,7 +167,9 @@ class PupguiGameListDialog(QObject):
             lblicon_item = QTableWidgetItem()
             lblicon_item.setData(Qt.DisplayRole, game.awacy_status.value)
             lblicon_item.setTextAlignment(Qt.AlignCenter)
-            lblicon_item.setData(Qt.UserRole, AWACY_WEB_URL)
+
+            search_str = ("" if game.awacy_status == AWACYStatus.UNKNOWN else game.game_name)
+            lblicon_item.setData(Qt.UserRole, AWACY_WEB_URL.format(GAMENAME=search_str))
 
             self.ui.tableGames.setItem(i, 3, lblicon_item)
             self.ui.tableGames.setCellWidget(i, 3, lblicon)
@@ -169,13 +180,13 @@ class PupguiGameListDialog(QObject):
         """ update the game list for the Lutris launcher """
         # Filter blank runners and Steam games, because we can't change any compat tool options for Steam games via Lutris
         # Steam games can be seen from the Steam games list, so no need to duplicate it here
-        self.games = list(filter(lambda lutris_game: (lutris_game.runner is not None and lutris_game.runner != 'steam' and len(lutris_game.runner) > 0), get_lutris_game_list(self.install_loc)))
+        self.games: list[LutrisGame] = [game for game in get_lutris_game_list(self.install_loc) if self.is_valid_lutris_gameslist_game(game)]
 
         self.ui.tableGames.setRowCount(len(self.games))
 
         # Not sure if we can allow compat tool updating from here, as Lutris allows configuring more than just Wine version
         # It lets you set Wine/DXVK/vkd3d/etc independently, so for now the dialog just displays game information
-        for i, game in enumerate(self.games): 
+        for i, game in enumerate(self.games):
             name_item = QTableWidgetItem(game.name)
             name_item.setToolTip(f'{game.name} ({game.slug})')
             if game.installer_slug:
@@ -201,16 +212,25 @@ class PupguiGameListDialog(QObject):
                 runner_item.setToolTip(tooltip)
 
             # Some games may be in Lutris but not have a valid install path, though the yml should *usually* have some path
-            install_dir_text = game.install_dir or self.tr('Unknown')
+            install_dir_text = game.install_dir
             install_dir_item = QTableWidgetItem(install_dir_text)
             self.set_item_data_directory(install_dir_item, install_dir_text)
 
-            install_date = datetime.fromtimestamp(int(game.installed_at)).isoformat().split('T')
-            install_date_short = f'{install_date[0]}'
-            install_date_tooltip = self.tr('Installed at {DATE} ({TIME})').format(DATE=install_date[0], TIME=install_date[1])
+            # Populate Install Date column if we have game.install_date
+            # Otherwise set to some safe Unknown values
+            if game.installed_at:
+                install_date = datetime.fromtimestamp(int(game.installed_at)).isoformat().split('T')
+                install_date_short = f'{install_date[0]}'
+                install_date_tooltip = self.tr('Installed at {DATE} ({TIME})').format(DATE=install_date[0], TIME=install_date[1])
+                install_date_data = int(game.installed_at)
+            else:
+                install_date = self.tr('Unknown')
+                install_date_short = self.tr('Unknown')
+                install_date_tooltip = self.tr('Install Date is Unknown')
+                install_date_data = 0
 
             install_date_item = QTableWidgetItem(install_date_short)
-            install_date_item.setData(Qt.UserRole, int(game.installed_at))
+            install_date_item.setData(Qt.UserRole, install_date_data)
             install_date_item.setToolTip(install_date_tooltip)
             install_date_item.setTextAlignment(Qt.AlignCenter)
 
@@ -221,7 +241,7 @@ class PupguiGameListDialog(QObject):
 
     def update_game_list_heroic(self):
         heroic_dir = os.path.join(os.path.expanduser(self.install_loc.get('install_dir')), '../..')
-        self.games = list(filter(lambda heroic_game: (heroic_game.is_installed and len(heroic_game.runner) > 0 and not heroic_game.is_dlc), get_heroic_game_list(heroic_dir)))
+        self.games: list[HeroicGame] = list(filter(lambda heroic_game: (heroic_game.is_installed and len(heroic_game.runner) > 0 and not heroic_game.is_dlc), get_heroic_game_list(heroic_dir)))
 
         self.ui.tableGames.setRowCount(len(self.games))
 
@@ -236,8 +256,8 @@ class PupguiGameListDialog(QObject):
             title_item.setToolTip(title_tooltip)
 
             compat_item = QTableWidgetItem()
-            # If no wine_info, assume this is a native game -- May be more reliable than checking a platform string
-            if game.wine_info.get('name', ''):
+            # Wine games
+            if game.platform.lower() == 'windows':
                 compat_item_text = game.wine_info.get('name', '').split('-', 1)[1].strip()
                 compat_tool_bin_path = game.wine_info.get('bin', '')
 
@@ -249,15 +269,20 @@ class PupguiGameListDialog(QObject):
                     compat_item.setData(Qt.UserRole, lambda path: os.system(f'xdg-open "{compat_tool_folder}"'))
                 compat_tool_tooltip += self.tr('\nType: {wine_type}').format(wine_type=game.wine_info.get("type", "").capitalize()) if game.wine_info.get('type', '') else ''
             else:
-                compat_item_text = self.tr('Native')
-                compat_tool_tooltip = self.tr('Type: Native')
+                # Linux/Browser games
+                compat_item_text = self.tr('Browser') if game.platform.lower() == 'browser' else self.tr('Native')
+                compat_tool_tooltip = self.tr('Type: {PLATFORM}').format(PLATFORM=game.platform)
 
             compat_item.setText(compat_item_text)
             compat_item.setToolTip(compat_tool_tooltip)
             compat_item.setTextAlignment(Qt.AlignCenter)
 
             install_path_item = QTableWidgetItem(game.install_path)
-            self.set_item_data_directory(install_path_item, game.install_path)
+            if game.platform.lower() == 'browser':
+                # Browser game paths are browserUrl, so the path won't exist -- Ignore this and set the tooltip and xdg-open action to open the URL 
+                self.set_item_data_directory(install_path_item, game.install_path, tooltip_exists=self.tr('Double-click to open in browser'), ignore_invalid_path=True)
+            else:
+                self.set_item_data_directory(install_path_item, game.install_path)
             
             runner_item = QTableWidgetItem(game.runner)
             runner_item.setTextAlignment(Qt.AlignCenter)
@@ -286,6 +311,13 @@ class PupguiGameListDialog(QObject):
         elif is_heroic_launcher(self.launcher):
             self.update_game_list_heroic()
 
+        self.update_tooltip()
+
+    def update_tooltip(self):
+        # If game is not found, fall back to tooltip defined in UI file
+        if tooltip_game_name := get_random_game_name(self.games):
+            self.ui.searchBox.setToolTip(self.tr('e.g. {GAME_NAME}').format(GAME_NAME=tooltip_game_name))
+
     def btn_search_clicked(self):
         self.ui.searchBox.setVisible(not self.ui.searchBox.isVisible())
         self.ui.btnSearch.setText(self.tr('Done') if self.ui.searchBox.isVisible() else self.tr('Search'))  # "Done" is not good text, try something else
@@ -294,6 +326,12 @@ class PupguiGameListDialog(QObject):
 
         self.search_gamelist_games(self.ui.searchBox.text() if self.ui.searchBox.isVisible() else '')
 
+        self.update_tooltip()
+
+    def btn_shortcut_editor_clicked(self):
+        self.ui.close()
+        PupguiShortcutDialog(self.install_loc.get('vdf_dir'), self.game_property_changed, self.ui)
+
     def search_gamelist_games(self, text):
         for row in range(self.ui.tableGames.rowCount()):
             should_hide: bool = not text.lower() in self.ui.tableGames.item(row, 0).text().lower()
@@ -345,7 +383,8 @@ class PupguiGameListDialog(QObject):
 
     def set_item_data_directory(self, item: QTableWidgetItem, path: str,
                                     tooltip_exists: str = 'Double click to browse...',
-                                    tooltip_invalid: str = 'Install location does not exist!'):
+                                    tooltip_invalid: str = 'Install location does not exist!',
+                                    ignore_invalid_path: bool = False):
         """ Set the Qt.UserRole data for a QTableWidgetItem to a lambda which uses xdg-open to open a given path, if it exists. """
 
         # (hacky way to) show default tooltips in parameters while allowing translation (make sure they match the default parameters)
@@ -354,13 +393,13 @@ class PupguiGameListDialog(QObject):
         if tooltip_invalid == 'Install location does not exist!':
             tooltip_invalid = self.tr('Install location does not exist!')
 
-        if os.path.isdir(path):
+        if os.path.isdir(path) or ignore_invalid_path:
             item.setToolTip(tooltip_exists)
             item.setData(Qt.UserRole, lambda path: os.system(f'xdg-open "{path}"'))
         else:
             item.setToolTip(tooltip_invalid)
 
-    def get_steamapp_awacystatus(self, game: SteamApp) -> Tuple[str, str]:
+    def get_steamapp_awacystatus(self, game: SteamApp) -> tuple[str, str]:
         """ Return translated status text and icon representing AreWeAntiCheatYet.com status for a Steam game """
         awacy_status: str = ''
         awacy_icon: str = ''
@@ -379,7 +418,7 @@ class PupguiGameListDialog(QObject):
             awacy_icon = 'awacy_broken.png'
         elif game.awacy_status == AWACYStatus.DENIED:
             awacy_status = self.tr('Linux support was explicitly denied')
-            awacy_status = 'awacy_denied.png'
+            awacy_icon = 'awacy_denied.png'
         else:
             awacy_status = self.tr('Anti-Cheat status unknown')
             awacy_icon = 'awacy_unknown.png'
@@ -411,3 +450,32 @@ class PupguiGameListDialog(QObject):
                 return self.tr('Verified for {compat_tool}').format(compat_tool=deckt)
         else:
             return ''
+
+    def is_valid_lutris_gameslist_game(self, game: LutrisGame) -> bool:
+        """
+        Check if a LutrisGame should be displayed on the Games List based on some criteria.
+        * Steam Games are excluded.
+        * Games with no runner are excluded.
+        * Games with no install_dir are excluded.
+
+        Return Type: bool
+        """
+
+        # Lutris DB may store Steam games even if they are not installed
+        #
+        # This results in only the game.name being available, and many
+        # other values like game.runner and game.install_dir being 'None'
+        #
+        # We can assume a game is not valid to display on the Games List
+        # if the runner and install_dir are Falsey, and if 
+
+        if not game.runner:
+            return False
+
+        if not game.install_dir:
+            return False
+
+        if is_lutris_game_using_runner(game, 'steam'):
+            return False
+
+        return True
