@@ -12,6 +12,7 @@ from pupgui2.datastructures import MsgBoxType, MsgBoxResult
 from pupgui2.steamutil import get_fish_user_paths, remove_steamtinkerlaunch, get_external_steamtinkerlaunch_intall
 from pupgui2.util import host_which, config_advanced_mode
 from pupgui2.util import ghapi_rlcheck
+from pupgui2.util import build_headers_with_authorization
 
 
 CT_NAME = 'SteamTinkerLaunch'
@@ -37,7 +38,7 @@ On <b>Steam Deck</b>, relevant dependencies will be installed for you. If you ar
 More information is available on the SteamTinkerLaunch Installation wiki page.
 <br/><br/>
 SteamTinkerLaunch has a number of <b>Optional Dependencies</b> which have to be installed separately for extra functionality. Please see the Optional Dependencies section
-of the SteamTinkerLaunch Installation guide on its GitHub page..''')}
+of the SteamTinkerLaunch Installation guide on its GitHub page.''')}
 
 
 class CtInstaller(QObject):
@@ -59,9 +60,13 @@ class CtInstaller(QObject):
         self.p_download_canceled = False
         self.remove_existing_installation = False
         self.main_window = main_window
-        self.rs = main_window.rs or requests.Session()
+
+        self.rs = requests.Session()
+        rs_headers = build_headers_with_authorization({}, main_window.web_access_tokens, 'github')
+        self.rs.headers.update(rs_headers)
+
         self.allow_git = allow_git
-        proc_prefix = ['flatpak-spawn', '--host'] if os.path.exists('/.flatpak-info') else []
+        proc_prefix = ['flatpak-spawn', '--host'] if constants.IS_FLATPAK else []
         self.distinfo = subprocess.run(
             proc_prefix + ['cat', '/etc/lsb-release', '/etc/os-release'],
             universal_newlines=True,
@@ -167,7 +172,7 @@ class CtInstaller(QObject):
         Return Type: bool
         """
         # Possibly excuse some of these if not on Steam Deck and ignore if Flatpak
-        proc_prefix = ['flatpak-spawn', '--host'] if os.path.exists('/.flatpak-info') else []
+        proc_prefix = ['flatpak-spawn', '--host'] if constants.IS_FLATPAK else []
         yad_exe = host_which('yad')
         if yad_exe:
             try:
@@ -190,7 +195,7 @@ class CtInstaller(QObject):
                 'xprop': host_which('xprop'),
                 'xrandr': host_which('xrandr'),
                 'xxd': host_which('xxd'),
-                'xwinfo': host_which('xwininfo'),
+                'xwininfo': host_which('xwininfo'),
                 'yad >= 7.2': yad_exe and yad_ver >= 7.2
             }
 
@@ -203,13 +208,13 @@ class CtInstaller(QObject):
 
         return False  # Installation would fail without dependencies.
 
-    def fetch_releases(self, count=100):
+    def fetch_releases(self, count=100, page=1):
         """
         List available releases or available branches for SteamTinkerLaunch-git
         Return Type: str[]
         """
         main_branch = 'master'
-        j = ghapi_rlcheck(self.rs.get(f'{self.CT_URL}?per_page={str(count)}').json())
+        j = ghapi_rlcheck(self.rs.get(f'{self.CT_URL}?per_page={count}&page={page}').json())
         if 'message' in j:
             return []
         branches = [branch['name'] for branch in self.rs.get(self.CT_BRANCHES_URL).json()] if self.allow_git else [release['tag_name'] for release in j]
@@ -290,7 +295,7 @@ class CtInstaller(QObject):
             os.chdir(stl_path)
 
             # ProtonUp-Qt Flatpak: Run STL on host system
-            stl_proc_prefix = ['flatpak-spawn', '--host'] if os.path.exists('/.flatpak-info') else []
+            stl_proc_prefix = ['flatpak-spawn', '--host'] if constants.IS_FLATPAK else []
 
             # If on Steam Deck, run script for initial Steam Deck config
             # On Steam Deck, STL is installed to "/home/deck/stl/prefix"
@@ -370,7 +375,7 @@ class CtInstaller(QObject):
                 pup_stl_path_date = f'# Added by ProtonUp-Qt on {datetime.datetime.now().strftime("%d-%m-%Y %H:%M:%S")}'
                 pup_stl_path_line = f'if [ -d "{stl_path}" ]; then export PATH="$PATH:{stl_path}"; fi'
                 present_shell_files = [
-                    os.path.join(os.path.expanduser('~'), f) for f in os.listdir(os.path.expanduser('~')) if os.path.isfile(os.path.join(os.path.expanduser('~'), f)) and f in constants.STEAM_STL_SHELL_FILES
+                    os.path.join(constants.HOME_DIR, f) for f in os.listdir(constants.HOME_DIR) if os.path.isfile(os.path.join(constants.HOME_DIR, f)) and f in constants.STEAM_STL_SHELL_FILES
                 ]
                 if os.path.exists(constants.STEAM_STL_FISH_VARIABLES):
                     present_shell_files.append(constants.STEAM_STL_FISH_VARIABLES)
@@ -398,7 +403,7 @@ class CtInstaller(QObject):
             print('Adding SteamTinkerLaunch as a compatibility tool...')
             subprocess.run(stl_proc_prefix + ['./steamtinkerlaunch', 'compat', 'add'])
 
-            os.chdir(os.path.expanduser('~'))
+            os.chdir(constants.HOME_DIR)
 
         protondir = os.path.join(install_dir, 'SteamTinkerLaunch')
 
